/*
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *   * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 */

package org.apache.commons.vfs.provider.truezip.test;

import org.apache.commons.vfs.test.AbstractProviderTestConfig;
import org.apache.commons.vfs.test.ProviderTestConfig;
import org.apache.commons.vfs.test.ProviderTestSuite;
import org.apache.commons.vfs.provider.truezip.TzFileProvider;
import org.apache.commons.vfs.impl.DefaultFileSystemManager;
import org.apache.commons.vfs.FileObject;
import org.apache.commons.vfs.FileSystemManager;
import org.apache.commons.AbstractVfsTestCase;
import junit.framework.Test;

import java.io.File;

/**
 * Tests for the Zip file system.
 *
 */
public class TrueZipProviderTestCase
    extends AbstractProviderTestConfig
    implements ProviderTestConfig {
    /**
     * Creates the test suite for the zip file system.
     */
    public static Test suite() throws Exception
    {
        return new ProviderTestSuite(new TrueZipProviderTestCase());
    }

    /**
     * Prepares the file system manager.
     */
    public void prepare(final DefaultFileSystemManager manager) throws Exception
    {
        manager.addProvider("zip", new TzFileProvider());
        manager.addExtensionMap("zip", "zip");
        manager.addMimeTypeMap("application/zip", "zip");
    }

    /**
     * Returns the base folder for read tests.
     */
    public FileObject getBaseTestFolder(final FileSystemManager manager) throws Exception
    {
        final File zipFile = AbstractVfsTestCase.getTestResource("test.zip");
        final String uri = "zip:" + zipFile.getAbsolutePath() + "!/";
        return manager.resolveFile(uri);
    }
}
